﻿package cust_Modules.Controls
{
    import flash.display.*;
    import flash.events.*;
    import flash.geom.*;
	import cust_Modules.Controls.SliderEvents.*

    public class Slider extends Control
    {
        protected var scrollDirection:int = 1;
        protected var barWidth:int;
        protected var barHeight:int;
        protected var background:MovieClip;
        protected var bar:MovieClip;
        protected var min:Number = 0;
        protected var max:Number = 1;
        protected var currentValue:Number = 0;
        protected var dragging:Boolean = false;

        public function Slider(param1:Number, param2:Number)
        {
            this.background = new MovieClip();
            this.bar = new MovieClip();
            addChild(this.background);
            addChild(this.bar);
            this.barWidth = param1;
            this.barHeight = param2;
            return;
        }// end function

        override protected function controlAdded(event:Event)
        {
            addEventListener(Event.ENTER_FRAME, this.tick);
            addEventListener(MouseEvent.MOUSE_DOWN, this.dragged);
            this.refreshColours();
            return;
        }// end function

        override protected function controlRemoved(event:Event)
        {
            removeEventListener(Event.ENTER_FRAME, this.tick);
            removeEventListener(MouseEvent.MOUSE_DOWN, this.dragged);
            return;
        }// end function

        override protected function refreshControl()
        {
            this.refreshColours();
            return;
        }// end function

        protected function refreshColours()
        {
            ControlGraphics.drawRect(this.background, new Rectangle(0, 0, this.barWidth, this.barHeight), backgroundIdleCol, outlineCol);
            this.refreshSlider();
            return;
        }// end function

        public function get value() : Number
        {
            return this.currentValue;
        }// end function

        public function dragged(event:MouseEvent) : void
        {
            this.dragging = true;
            stage.addEventListener(MouseEvent.MOUSE_UP, this.mouseReleased);
            dispatchEvent(new SliderClickedEvent(this));
            return;
        }// end function

        public function mouseReleased(event:MouseEvent) : void
        {
            if (this.dragging)
            {
                this.setValueRatio(mouseX);
                dispatchEvent(new SliderChangedEvent(this, true));
                dispatchEvent(new SliderReleasedEvent(this));
                this.dragging = false;
            }
            stage.removeEventListener(MouseEvent.MOUSE_UP, this.mouseReleased);
            return;
        }// end function

        public function tick(event:Event) : void
        {
            if (this.dragging)
            {
                this.setValueRatio(mouseX);
                dispatchEvent(new SliderChangedEvent(this, true));
            }
            this.refreshSlider();
            return;
        }// end function

        private function setValueRatio(param1:Number) : void
        {
            var _loc_2:* = Math.max(Math.min(1, param1 / this.barWidth), 0);
            this.setValue(_loc_2 * (this.max - this.min) + this.min);
            return;
        }// end function

        public function setValue(param1:Number)
        {
            this.currentValue = param1;
            this.refreshSlider();
            dispatchEvent(new SliderChangedEvent(this, false));
            return;
        }// end function

        public function setMin(param1:Number) : void
        {
            var _loc_2:* = this.getPercentage();
            if (param1 < this.max)
            {
                this.min = Math.min(param1, this.max);
            }
            this.setPercentage(_loc_2);
            this.refreshSlider();
            return;
        }// end function

        public function setMax(param1:Number) : void
        {
            var _loc_2:* = this.getPercentage();
            if (param1 > this.min)
            {
                this.max = Math.max(this.min, param1);
            }
            this.setPercentage(_loc_2);
            this.refreshSlider();
            return;
        }// end function

        public function get sliderMin() : Number
        {
            return this.min;
        }// end function

        public function get sliderMax() : Number
        {
            return this.max;
        }// end function

        public function setPercentage(param1:Number) : void
        {
            this.setValue(Math.min(Math.max(param1, 0), 100) / 100 * (this.max - this.min) + this.min);
            return;
        }// end function

        public function getPercentage() : Number
        {
            var _loc_1:* = -this.min;
            return (this.currentValue + _loc_1) / (this.max + _loc_1) * 100;
        }// end function

        protected function refreshSlider() : void
        {
            var _loc_1:* = new Rectangle(0, 0, Math.max(Math.min(this.barWidth * ((this.currentValue - this.min) / (this.max - this.min)), this.barWidth), 0), this.barHeight);
            ControlGraphics.drawRect(this.bar, _loc_1, glyphIdleCol, 0, 1, 0, 0, true);
            if (hover)
            {
                ControlGraphics.drawRect(this.bar, _loc_1, glyphHoverCol, 0, 1, 0, 0, false);
            }
            if (this.dragging)
            {
                ControlGraphics.drawRect(this.bar, _loc_1, glyphIdleCol, 0, 1, 0, 0, false);
            }
            ControlGraphics.drawRect(this.bar, new Rectangle(0, 0, this.barWidth, this.barHeight), 0, outlineCol, 0, 1, outlineThickness, false);
            return;
        }// end function

        public function reverseScrollingDirection() : void
        {
            this.scrollDirection = this.scrollDirection * -1;
            return;
        }// end function

        public function passMouseWheel(event:MouseEvent)
        {
            this.setPercentage(this.getPercentage() + event.delta * 2 * this.scrollDirection);
            return;
        }// end function

    }
}
